@@ -12,10 +12,8 @@ class InvenioI18NSetupCfgBuilder(OutputBuilder):
 
         output: CFGOutput = self.builder.get_output("cfg", "setup.cfg")
 
-        translation_package = package_name(self.current_model.package)
-
         output.add_entry_point(
             "invenio_i18n.translations",
             self.current_model.translations_setup_cfg,
-            translation_package,
+            self.current_model.package,
         )
